<?php

namespace Drupal\travolute\ValueObject;


use Carbon\Carbon;

final class AccommodationParameters
{
    private $departureDate;
    private $returnDate;
    private $departureOffset;
    private $query;
    private $minimumNumberOfStars;
    private $durations;
    private $boardTypes;
    private $occupancy;
    private $offset;
    private $limit;
    private $airport;

  /**
   * AccommodationParameters constructor.
   *
   * @param $postData
   * @throws \Exception
   */
    public function __construct($postData) {
        $this->departureDate = (!empty($postData['departure_date']) ? new Carbon($postData['departure_date']) : null);
        $this->returnDate = (!empty($postData['return_date']) ? new Carbon($postData['return_date']) : null);
        $this->departureOffset = (!empty($postData['departure_offset']) ? $postData['departure_offset'] : null);
        $this->query = (!empty($postData['query']) ? $postData['query'] : null);
        $this->minimumNumberOfStars = (!empty($postData['stars']) ? $postData['stars'] : null);
        $this->durations = (!empty($postData['durations']) ? $postData['durations'] : null);
        $this->boardTypes = (!empty($postData['boardType']) ? $postData['boardType'] : null);
        $this->occupancy = (!empty($postData['occupancy']) ? $postData['occupancy'] : 2);
        $this->offset = (!empty($postData['offset']) ? $postData['offset'] : 0);
        $this->limit = (!empty($postData['limit']) ? $postData['limit'] : 20);
        $this->airport = (!empty($postData['airport']) ? $postData['airport'] : null);
    }

    /**
     * @return Carbon
     */
    public function getDepartureDate(): Carbon
    {
        return $this->departureDate;
    }

    /**
     * @return Carbon
     */
    public function getReturnDate(): Carbon
    {
        return $this->returnDate;
    }

    /**
     * @return int
     */
    public function getDepartureOffset(): int
    {
        return $this->departureOffset;
    }

    /**
     * @return mixed
     */
    public function getQuery()
    {
        return $this->query;
    }

    /**
     * @return mixed
     */
    public function getMinimumNumberOfStars()
    {
        return $this->minimumNumberOfStars;
    }

    /**
     * @return mixed
     */
    public function getDurations()
    {
        return $this->durations;
    }

    /**
     * @return array
     */
    public function getBoardTypes(): array
    {
        return $this->boardTypes;
    }

    /**
     * @return int
     */
    public function getOccupancy(): int
    {
        return $this->occupancy;
    }

    /**
     * @return int
     */
    public function getOffset(): int
    {
        return $this->offset;
    }

    /**
     * @return int
     */
    public function getLimit(): int
    {
        return $this->limit;
    }

    /**
     * @return array|null
     */
    public function getAirport(): ?array
    {
        return $this->airport;
    }

    public function toArray()
    {
        $output = [
            'occupancy' => $this->getOccupancy(),
            'offset' => $this->getOffset(),
            'limit' => $this->getLimit(),
        ];

        if ($this->departureDate instanceof Carbon) {
            $output['departure_date'] = $this->getDepartureDate()->format('Y-m-d');
        }

        if ($this->returnDate instanceof Carbon) {
            $output['return_date'] = $this->getReturnDate()->format('Y-m-d');
        }

        if ($this->departureOffset !== null) {
            $output['departure_offset'] = $this->getDepartureOffset();
        }

        if (\is_string($this->query)) {
            $output['query'] = $this->getQuery();
        }

        if (\is_int($this->minimumNumberOfStars)) {
            $output['stars'] = $this->getMinimumNumberOfStars();
        }

        if (\is_array($this->durations)) {
            $output['duration'] = $this->getDurations();
        }

        if (\is_array($this->airport)) {
            $output['airport'] = $this->getAirport();
        }

        if (\is_array($this->boardTypes)) {
            $output['boardtype'] = $this->getBoardTypes();
        }

        return $output;
    }
}
